=== modified file 'NEWS'
--- NEWS	2007-06-01 22:16:55 +0000
+++ NEWS	2007-06-01 23:10:18 +0000
@@ -24,6 +24,11 @@
     * Revert does not try to preserve file contents that were originally
       produced by reverting to a historical revision.  (Aaron Bentley)
 
+    * ``bzr log --short`` now includes ``[merge]`` for revisions which
+      have more than one parent. This is a small improvement to help
+      understanding what changes have occurred
+      (John Arbash Meinel, #83887)
+
   BUGFIXES:
 
     * ``bzr push`` should only connect to the remote location one time.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2007-05-25 04:00:47 +0000
+++ bzrlib/log.py	2007-06-01 21:40:45 +0000
@@ -567,15 +567,19 @@
         from bzrlib.osutils import format_date
 
         to_file = self.to_file
-        date_str = format_date(revision.rev.timestamp, 
+        date_str = format_date(revision.rev.timestamp,
                                revision.rev.timezone or 0,
                                self.show_timezone)
-        print >>to_file, "%5s %s\t%s" % (revision.revno, 
+        is_merge = ''
+        if len(revision.rev.parent_ids) > 1:
+            is_merge = ' [merge]'
+        print >>to_file, "%5s %s\t%s%s" % (revision.revno,
                 self.short_committer(revision.rev),
-                format_date(revision.rev.timestamp, 
+                format_date(revision.rev.timestamp,
                             revision.rev.timezone or 0,
                             self.show_timezone, date_fmt="%Y-%m-%d",
-                            show_offset=False))
+                            show_offset=False),
+                is_merge)
         if self.show_ids:
             print >>to_file,  '      revision-id:', revision.rev.revision_id
         if not revision.rev.message:

=== modified file 'bzrlib/tests/test_log.py'
--- bzrlib/tests/test_log.py	2007-05-24 12:13:06 +0000
+++ bzrlib/tests/test_log.py	2007-06-01 21:40:45 +0000
@@ -280,6 +280,37 @@
         log_contents = logfile.read()
         self.assertEqualDiff(log_contents, '1: Line-Log-Formatte... 2005-11-23 add a\n')
 
+    def test_short_log_with_merges(self):
+        wt = self.make_branch_and_memory_tree('.')
+        wt.lock_write()
+        try:
+            wt.add('')
+            wt.commit('rev-1', rev_id='rev-1',
+                      timestamp=1132586655, timezone=36000,
+                      committer='Joe Foo <joe@foo.com>')
+            wt.commit('rev-merged', rev_id='rev-2a',
+                      timestamp=1132586700, timezone=36000,
+                      committer='Joe Foo <joe@foo.com>')
+            wt.set_parent_ids(['rev-1', 'rev-2a'])
+            wt.branch.set_last_revision_info(1, 'rev-1')
+            wt.commit('rev-2', rev_id='rev-2b',
+                      timestamp=1132586800, timezone=36000,
+                      committer='Joe Foo <joe@foo.com>')
+            logfile = StringIO()
+            formatter = ShortLogFormatter(to_file=logfile)
+            show_log(wt.branch, formatter)
+            logfile.flush()
+            self.assertEqualDiff("""\
+    2 Joe Foo\t2005-11-22 [merge]
+      rev-2
+
+    1 Joe Foo\t2005-11-22
+      rev-1
+
+""", logfile.getvalue())
+        finally:
+            wt.unlock()
+
     def make_tree_with_commits(self):
         """Create a tree with well-known revision ids"""
         wt = self.make_branch_and_tree('tree1')

